@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -17,6 +17,7 @@
 #include "compoundhandler.h"
 #include "sectionhandler.h"
 #include "memberhandler.h"
+#include "dochandler.h"
 #include "debug.h"
 
 class SectionTypeMap
@@ -33,6 +34,7 @@ class SectionTypeMap
       m_map.insert("signal",new int(ISection::Signals));
       m_map.insert("dcop-func",new int(ISection::DCOPFuncs));
       m_map.insert("property",new int(ISection::Properties));
+      m_map.insert("event",new int(ISection::Events));
       m_map.insert("public-static-func",new int(ISection::PubStatFuncs));
       m_map.insert("public-static-attrib",new int(ISection::PubStatAttribs));
       m_map.insert("protected-type",new int(ISection::ProTypes));
@@ -95,6 +97,7 @@ SectionHandler::SectionHandler(IBaseHandler *parent) : m_parent(parent)
   addStartHandler("memberdef",this,&SectionHandler::startMember);
   addStartHandler("header",this,&SectionHandler::startHeader);
   addEndHandler("header",this,&SectionHandler::endHeader);
+  addStartHandler("description",this,&SectionHandler::startDescription);
 }
 
 SectionHandler::~SectionHandler()
@@ -110,6 +113,13 @@ void SectionHandler::startSection(const QXmlAttributes& attrib)
   debug(2,"section kind=`%s'\n",m_kindString.data());
 }
 
+void SectionHandler::startDescription(const QXmlAttributes& attrib)
+{
+  DocHandler *docHandler = new DocHandler(this);
+  docHandler->startDoc(attrib);
+  m_description = docHandler;
+}
+
 void SectionHandler::endSection()
 {
   m_parent->setDelegate(0);
@@ -146,6 +156,11 @@ void SectionHandler::initialize(CompoundHandler *ch)
   }
 }
 
+IDocRoot *SectionHandler::description() const 
+{ 
+  return m_description; 
+}
+
 IMemberIterator *SectionHandler::members() const 
 { 
   return new MemberIterator(m_members); 
