@@ -221,9 +221,6 @@ Step2::Step2(QWidget *parent) : QWidget(parent,"Step2")
   layout->addWidget(m_optimizeLang);
 
   layout->addStretch(1);
-
-  connect(m_crossRef,SIGNAL(stateChanged(int)),
-          parent,SLOT(changeCrossRefState(int)));
 }
 
 bool Step2::crossReferencingEnabled() const
@@ -621,44 +618,6 @@ Wizard::Wizard(QWidget *parent=0) : QTabDialog(parent)
   setCancelButton();
 }
 
-void Wizard::changeCallGraphState(int state)
-{
-  if (state==QButton::On && !m_step2->crossReferencingEnabled())
-  {
-    if (QMessageBox::question(this,"This option depends on another option",
-                              "The call graph option requires that cross-referencing "
-                              "of source code is enabled.\nDo you want to enable this "
-                              "option?",QMessageBox::Yes,QMessageBox::No)==QMessageBox::Yes)
-    {
-      m_step2->enableCrossReferencing();
-    }
-    else
-    {
-      m_step4->disableCallGraphs();
-    }
-  }
-}
-
-void Wizard::changeCrossRefState(int state)
-{
-  if (state==QButton::Off && m_step4->callGraphEnabled())
-  {
-    if (QMessageBox::question(this,"Another option depends on this one",
-                              "The call graph option requires that cross-referencing "
-                              "of source code is enabled.\nDo you want to disable the call "
-                              "graph option?",QMessageBox::Yes,QMessageBox::No
-                             )==QMessageBox::Yes
-       )
-    {
-      m_step4->disableCallGraphs();
-    }
-    else
-    {
-      m_step2->enableCrossReferencing();
-    }
-  }
-}
-
 //==========================================================================
 
 MainWidget::MainWidget(QWidget *parent) 
@@ -1103,10 +1062,14 @@ void MainWidget::launchWizard()
         break;
     }
 #if defined(Q_OS_MACX)
-    if (Config_getBool("HAVE_DOT"))
+    if (Config_getString("DOT_PATH").isEmpty())
     {
       setDotPath();
     }
+    if (Config_getString("MSCGEN_PATH").isEmpty())
+    {
+      setMscgenPath();
+    }
 #endif
     setConfigSaved(FALSE);
   }
@@ -1142,6 +1105,18 @@ void MainWidget::loadConfigFromFile(const QString &fn)
     addRecentFile(fn);
     m_workingDir->setText(QFileInfo(fn).dirPath(TRUE));
     m_configFileName = fn;
+#if defined(Q_OS_MACX)
+    if (Config_getString("DOT_PATH").isEmpty())
+    {
+      setDotPath();
+      setConfigSaved(FALSE);
+    }
+    if (Config_getString("MSCGEN_PATH").isEmpty())
+    {
+      setMscgenPath();
+      setConfigSaved(FALSE);
+    }
+#endif
     statusBar()->message("New configuration loaded",messageTimeout);
   }
 }
@@ -1228,6 +1203,7 @@ void MainWidget::resetConfig()
     Config::instance()->init();
 #if defined(Q_OS_MACX)
     setDotPath();
+    setMscgenPath();
 #endif
 
     m_configFileName = "";
@@ -1322,7 +1298,7 @@ void MainWidget::about()
   QTextStream t(&msg,IO_WriteOnly);
   t << QString("<qt><center>A tool to configure and run doxygen version ")+versionString+
        " on your source files.</center><p><br>"
-       "<center>Written by<br> Dimitri van Heesch<br>&copy; 2000-2006</center><p>"
+       "<center>Written by<br> Dimitri van Heesch<br>&copy; 2000-2008</center><p>"
        "</qt>";
   QMessageBox::about(this,"Doxygen GUI",msg);
 }
