@@ -3,7 +3,7 @@
  * $Id: diagram.cpp,v 1.30 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -33,6 +33,7 @@
 //#include "latexgen.h"
 //#include "htmlgen.h"
 #include "doxygen.h"
+#include "portable.h"
 
 //-----------------------------------------------------------------------------
 
@@ -258,14 +259,17 @@ void DiagramRow::insertClass(DiagramItem *parent,ClassDef *cd,bool doBases,
   di->move(count()*gridWidth,level*gridHeight);
   append(di);
   BaseClassList *bcl=doBases ? cd->baseClasses() : cd->subClasses();
-  /* there are base/sub classes */
   int count=0;
-  BaseClassDef *bcd=bcl->first();
-  while (bcd)
+  if (bcl)
   {
-    ClassDef *ccd=bcd->classDef;
-    if (ccd && ccd->isVisibleInHierarchy() /*&& !ccd->visited*/) count++;
-    bcd=bcl->next();
+    /* there are base/sub classes */
+    BaseClassDef *bcd=bcl->first();
+    while (bcd)
+    {
+      ClassDef *ccd=bcd->classDef;
+      if (ccd && ccd->isVisibleInHierarchy() /*&& !ccd->visited*/) count++;
+      bcd=bcl->next();
+    }
   }
   if (count>0 && (prot!=Private || !doBases))
   {
@@ -925,7 +929,7 @@ void TreeDiagram::drawConnectors(QTextStream &t,Image *image,
 
 void clearVisitFlags()
 {
-  ClassSDict::Iterator cli(Doxygen::classSDict);
+  ClassSDict::Iterator cli(*Doxygen::classSDict);
   ClassDef *cd;
   for (;(cd=cli.current());++cli)
   {
@@ -964,7 +968,7 @@ ClassDiagram::~ClassDiagram()
 }
 
 void ClassDiagram::writeFigure(QTextStream &output,const char *path,
-                               const char *fileName)
+                               const char *fileName) const
 {
   uint baseRows=base->computeRows();
   uint superRows=super->computeRows();
@@ -1248,7 +1252,7 @@ void ClassDiagram::writeFigure(QTextStream &output,const char *path,
     epstopdfArgs.sprintf("\"%s.eps\" --outfile=\"%s.pdf\"",
                    epsBaseName.data(),epsBaseName.data());
     //printf("Converting eps using `%s'\n",epstopdfCmd.data());
-    if (iSystem("epstopdf",epstopdfArgs)!=0)
+    if (portable_system("epstopdf",epstopdfArgs)!=0)
     {
        err("Error: Problems running epstopdf. Check your TeX installation!\n");
        return;
@@ -1259,7 +1263,7 @@ void ClassDiagram::writeFigure(QTextStream &output,const char *path,
 
 void ClassDiagram::writeImage(QTextStream &t,const char *path,
                               const char *relPath,const char *fileName, 
-                              bool generateMap)
+                              bool generateMap) const
 {
   uint baseRows=base->computeRows();
   uint superRows=super->computeRows();
