@@ -2,7 +2,7 @@
  *
  * $Id: $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -62,6 +62,7 @@ class DirDef : public Definition
     bool isCluster() const { return m_subdirs.count()>0; }
     int level() const { return m_level; }
     DirDef *parent() const { return m_parent; }
+    int dirCount() const { return m_dirCount; }
     const QDict<UsedDir> *usedDirs() const { return m_usedDirs; }
     bool isParentOf(DirDef *dir) const;
     bool depGraphIsTrivial() const;
@@ -70,8 +71,6 @@ class DirDef : public Definition
     void writeDetailedDocumentation(OutputList &ol);
     void writeDocumentation(OutputList &ol);
     void writeDepGraph(QTextStream &t);
-    //void writePathFragment(OutputList &ol) const;
-    //void writeNavigationPath(OutputList &ol);
 
     static DirDef *mergeDirectoryInTree(const QCString &path);
     bool visited;
