@@ -3,7 +3,7 @@
  * $Id: doxygen.h,v 1.39 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -36,6 +36,8 @@
 #include "membergroup.h"
 #include "reflist.h"
 #include "dirdef.h"
+#include "index.h"
+#include "docsets.h"
 
 class PageSList;
 class PageSDict;
@@ -45,6 +47,8 @@ class DirDef;
 class ParserManager;
 class ObjCache;
 class Store;
+class QFileInfo;
+class BufStr;
 
 typedef QList<QCString>    StringList;
 typedef QDict<FileDef>     FileDict;
@@ -123,6 +127,9 @@ class Doxygen
     static Store                    *symbolStorage;
     static QCString                  objDBFileName;
     static QCString                  entryDBFileName;
+    static bool                      gatherDefines;
+    static bool                      userComments;
+    static IndexList                 indexList;
 };
 
 void initDoxygen();
@@ -130,6 +137,33 @@ void readConfiguration(int argc, char **argv);
 void checkConfiguration();
 void parseInput();
 void generateOutput();
+void readAliases();
+void readFormulaRepository();
+int readFileOrDirectory(const char *s,
+                        FileNameList *fnList,
+                        FileNameDict *fnDict,
+                        StringDict *exclDict,
+                        QStrList *patList,
+                        QStrList *exclPatList,
+                        StringList *resultList,
+                        StringDict *resultDict,
+                        bool recursive,
+                        bool errorIfNotExist=TRUE,
+                        QDict<void> *killDict = 0
+                       );
+int readDir(QFileInfo *fi,
+            FileNameList *fnList,
+            FileNameDict *fnDict,
+            StringDict  *exclDict,
+            QStrList *patList,
+            QStrList *exclPatList,
+            StringList *resultList,
+            StringDict *resultDict,
+            bool errorIfNotExist,
+            bool recursive,
+            QDict<void> *killDict
+           );
+void copyAndFilterFile(const char *fileName,BufStr &dest);
 
 #define NEWMATCH
 
