@@ -2,7 +2,7 @@
  *
  * $Id: latexgen.cpp,v 1.58 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -53,47 +53,6 @@
 //}
 
 
-static QCString escapeLabelName(const char *s)
-{
-  QCString result;
-  const char *p=s;
-  char c;
-  while ((c=*p++))
-  {
-    switch (c)
-    {
-      case '%': result+="\\%"; break;
-      case '|': result+="\\tt{\"|}"; break;
-      case '!': result+="\"!"; break;
-      default: result+=c;
-    }
-  }
-  return result;
-}
-
-static QCString escapeMakeIndexChars(LatexGenerator *g,QTextStream &t,const char *s)
-{
-  QCString result;
-  const char *p=s;
-  char str[2];
-  str[1]=0;
-  char c;
-  while ((c=*p++))
-  {
-    switch (c)
-    {
-      case '!': t << "\"!"; break;
-      case '"': t << "\"\""; break;
-      case '@': t << "\"@"; break;
-      case '|': t << "\\tt{\"|}"; break;
-      case '[': t << "["; break;
-      case ']': t << "]"; break;
-      default:  str[0]=c; g->docify(str); break;
-    }
-  }
-  return result;
-}
-
 
 LatexGenerator::LatexGenerator() : OutputGenerator()
 {
@@ -184,7 +143,8 @@ void LatexGenerator::init()
   }
   else // use pdflatex for higher quality output
   {
-    t << "all: clean refman.pdf" << endl << endl;
+    t << "all: clean refman.pdf" << endl << endl
+      << "pdf: refman.pdf" << endl << endl;
     t << "refman.pdf: refman.tex" << endl;
     t << "\tpdflatex refman.tex" << endl;
     t << "\tmakeindex refman.idx" << endl;
@@ -237,7 +197,15 @@ static void writeDefaultHeaderPart1(QTextStream &t)
   }
   if (Config_getBool("PDF_HYPERLINKS")) 
   {
-    t << "\\ifx\\pdfoutput\\undefined" << endl
+    t << "\\usepackage{ifpdf}" << endl
+      << "\\ifpdf" << endl
+      << "\\usepackage[pdftex," << endl
+      << "            pagebackref=true," << endl
+      << "            colorlinks=true," << endl
+      << "            linkcolor=blue," << endl
+      << "            unicode" << endl
+      << "           ]{hyperref}" << endl
+      << "\\else" << endl
       << "\\usepackage[ps2pdf," << endl
       << "            pagebackref=true," << endl
       << "            colorlinks=true," << endl
@@ -245,13 +213,6 @@ static void writeDefaultHeaderPart1(QTextStream &t)
       << "            unicode" << endl
       << "           ]{hyperref}" << endl
       << "\\usepackage{pspicture}" << endl
-      << "\\else" << endl
-      << "\\usepackage[pdftex," << endl
-      << "            pagebackref=true," << endl
-      << "            colorlinks=true," << endl
-      << "            linkcolor=blue," << endl
-      << "            unicode" << endl
-      << "           ]{hyperref}" << endl
       << "\\fi" << endl;
   }
   // Try to get the command for switching on the language
@@ -419,9 +380,7 @@ void LatexGenerator::writeHeaderFile(QFile &f)
 void LatexGenerator::writeStyleSheetFile(QFile &f)
 {
   QTextStream t(&f);
-#if QT_VERSION >= 200
-  t.setEncoding(QTextStream::Latin1);
-#endif
+  t.setEncoding(QTextStream::UnicodeUTF8);
 
   writeDefaultStyleSheetPart1(t);
   QCString &projectName = Config_getString("PROJECT_NAME");
@@ -429,12 +388,12 @@ void LatexGenerator::writeStyleSheetFile(QFile &f)
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2007";
+  //t << "Dimitri van Heesch \\copyright~1997-2008";
   writeDefaultStyleSheetPart2(t);
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2007";
+  //t << "Dimitri van Heesch \\copyright~1997-2008";
   writeDefaultStyleSheetPart3(t);
 }
 
@@ -815,6 +774,7 @@ void LatexGenerator::endIndexSection(IndexSections is)
     case isPageDocumentation:
       {
         t << "}\n";
+#if 0
         PageSDict::Iterator pdi(*Doxygen::pageSDict);
         PageDef *pd=pdi.toFirst();
         bool first=TRUE;
@@ -822,11 +782,16 @@ void LatexGenerator::endIndexSection(IndexSections is)
         {
           if (!pd->getGroupDef() && !pd->isReference())
           {
+             if (compactLatex) t << "\\section"; else t << "\\chapter";
+             t << "{" << pd->title();
+             t << "}\n";
+            
             if (compactLatex || first) t << "\\input" ; else t << "\\include";
             t << "{" << pd->getOutputFileBase() << "}\n";
             first=FALSE;
           }
         }
+#endif
       }
       break;
     case isEndIndex:
@@ -835,6 +800,15 @@ void LatexGenerator::endIndexSection(IndexSections is)
       break;
   }
 }
+
+void LatexGenerator::writePageLink(const char *name, bool first)
+{
+  bool &compactLatex = Config_getBool("COMPACT_LATEX");
+  if (compactLatex || first) t << "\\input" ; else t << "\\include";
+  t << "{" << name << "}\n";
+}
+
+
 void LatexGenerator::writeStyleInfo(int part)
 {
   switch(part)
@@ -852,14 +826,14 @@ void LatexGenerator::writeStyleInfo(int part)
       break;
     case 2:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2007";
+        //t << " Dimitri van Heesch \\copyright~1997-2008";
         t << "}]{}\n";
         writeDefaultStyleSheetPart2(t);
       }
       break;
     case 4:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2007";
+        //t << " Dimitri van Heesch \\copyright~1997-2008";
         writeDefaultStyleSheetPart3(t);
         endPlainFile();
       }
@@ -872,6 +846,15 @@ void LatexGenerator::newParagraph()
   t << endl << endl;
 }
 
+void LatexGenerator::startParagraph()
+{
+  t << endl << endl;
+}
+
+void LatexGenerator::endParagraph()
+{
+}
+
 void LatexGenerator::writeString(const char *text)
 {
   t << text;
@@ -1057,9 +1040,10 @@ void LatexGenerator::endTitleHead(const char *fileName,const char *name)
   t << "}" << endl;
   if (name)
   {
-    t << "\\label{" << fileName << "}\\index{" 
-      << name << "@{";
-    escapeMakeIndexChars(this,t,name);
+    t << "\\label{" << fileName << "}\\index{";
+    escapeLabelName(name);
+    t << "@{";
+    escapeMakeIndexChars(name);
     t << "}}" << endl;
   }
   if (Config_getBool("PDF_HYPERLINKS") && fileName)
@@ -1128,16 +1112,20 @@ void LatexGenerator::startMemberDoc(const char *clname,
     t << "\\index{";
     if (clname)
     {
-      t << clname << "@{";
-      docify(clname);
+      escapeLabelName(clname);
+      t << "@{";
+      escapeMakeIndexChars(clname);
       t << "}!";
     }
-    t << escapeLabelName(memname) << "@{";
-    escapeMakeIndexChars(this,t,memname);
+    escapeLabelName(memname);
+    t << "@{";
+    escapeMakeIndexChars(memname);
     t << "}}" << endl;
 
-    t << "\\index{" << escapeLabelName(memname) << "@{";
-    escapeMakeIndexChars(this,t,memname);
+    t << "\\index{";
+    escapeLabelName(memname);
+    t << "@{";
+    escapeMakeIndexChars(memname);
     t << "}";
     if (clname)
     {
@@ -1210,13 +1198,17 @@ void LatexGenerator::addIndexItem(const char *s1,const char *s2)
 {
   if (s1)
   {
-    t << "\\index{" << escapeLabelName(s1) << "@{";
-    escapeMakeIndexChars(this,t,s1);
+    t << "\\index{";
+    escapeLabelName(s1);
+    t << "@{";
+    escapeMakeIndexChars(s1);
     t << "}";
     if (s2)
     {
-      t << "!" << escapeLabelName(s2) << "@{";
-      escapeMakeIndexChars(this,t,s2);
+      t << "!";
+      escapeLabelName(s2);
+      t << "@{";
+      escapeMakeIndexChars(s2);
       t << "}";
     }
     t << "}";
@@ -1332,7 +1324,7 @@ void LatexGenerator::startClassDiagram()
   //t << "{";
 }
 
-void LatexGenerator::endClassDiagram(ClassDiagram &d,
+void LatexGenerator::endClassDiagram(const ClassDiagram &d,
                                        const char *fileName,const char *)
 {
   d.writeFigure(t,dir,fileName);
@@ -1345,9 +1337,9 @@ void LatexGenerator::startAnonTypeScope(int indent)
   {
     t << "\\begin{tabbing}" << endl;
     t << "xx\\=xx\\=xx\\=xx\\=xx\\=xx\\=xx\\=xx\\=xx\\=\\kill" << endl;
-    //printf("LatexGenerator::startMemberItem() insideTabbing=TRUE\n");
     insideTabbing=TRUE;
   }
+  m_indent=indent;
 }
 
 void LatexGenerator::endAnonTypeScope(int indent)
@@ -1357,6 +1349,7 @@ void LatexGenerator::endAnonTypeScope(int indent)
     t << endl << "\\end{tabbing}";
     insideTabbing=FALSE;
   }
+  m_indent=indent;
 }
 
 void LatexGenerator::startMemberTemplateParams()
@@ -1390,7 +1383,7 @@ void LatexGenerator::endMemberItem()
   if (insideTabbing)
   {
     t << "\\\\";
- } 
+  } 
   templateMemberItem = FALSE;
   t << endl; 
 }
@@ -1403,7 +1396,7 @@ void LatexGenerator::startMemberDescription()
   }
   else
   {
-    for (int i=0;i<m_indent+1;i++) t << "\\>";
+    for (int i=0;i<m_indent+2;i++) t << "\\>";
     t << "{\\em ";
   }
 }
@@ -1416,18 +1409,17 @@ void LatexGenerator::endMemberDescription()
   }
   else
   {
-    t << "}\\\\";
-    m_indent=0;
+    t << "}\\\\\n";
   }
 }
 
 
 void LatexGenerator::writeNonBreakableSpace(int) 
 {
+  //printf("writeNonBreakbleSpace()\n");
   if (insideTabbing)
   {
     t << "\\>";
-    m_indent++;
   }
   else
     t << "~"; 
@@ -1486,7 +1478,7 @@ void LatexGenerator::startDotGraph()
 {
 }
 
-void LatexGenerator::endDotGraph(DotClassGraph &g) 
+void LatexGenerator::endDotGraph(const DotClassGraph &g) 
 {
   g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
 }
@@ -1495,7 +1487,7 @@ void LatexGenerator::startInclDepGraph()
 {
 }
 
-void LatexGenerator::endInclDepGraph(DotInclDepGraph &g) 
+void LatexGenerator::endInclDepGraph(const DotInclDepGraph &g) 
 {
   g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
 }
@@ -1504,7 +1496,7 @@ void LatexGenerator::startGroupCollaboration()
 {
 }
 
-void LatexGenerator::endGroupCollaboration(DotGroupCollaboration &g) 
+void LatexGenerator::endGroupCollaboration(const DotGroupCollaboration &g) 
 {
   g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
 }
@@ -1513,7 +1505,7 @@ void LatexGenerator::startCallGraph()
 {
 }
 
-void LatexGenerator::endCallGraph(DotCallGraph &g) 
+void LatexGenerator::endCallGraph(const DotCallGraph &g) 
 {
   g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
 }
@@ -1522,7 +1514,7 @@ void LatexGenerator::startDirDepGraph()
 {
 }
 
-void LatexGenerator::endDirDepGraph(DotDirDeps &g) 
+void LatexGenerator::endDirDepGraph(const DotDirDeps &g) 
 {
   g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
 }
@@ -1589,6 +1581,13 @@ void LatexGenerator::endParamList()
   t << "\\end{Desc}" << endl;
 }
 
+void LatexGenerator::startParameterType(bool first,const char *key)
+{
+  if (!first)
+  {
+    t << "\\/ " << key << " ";
+  }
+}
 
 void LatexGenerator::printDoc(DocNode *n,const char *langExt)
 {
@@ -1597,3 +1596,84 @@ void LatexGenerator::printDoc(DocNode *n,const char *langExt)
   delete visitor; 
 }
 
+void LatexGenerator::startConstraintList(const char *header)
+{
+  t << "\\begin{Desc}\n\\item[";
+  docify(header);
+  t << "]";
+  t << "\\begin{description}" << endl;
+}
+
+void LatexGenerator::startConstraintParam()
+{
+  t << "\\item[{\\em ";
+}
+
+void LatexGenerator::endConstraintParam()
+{
+}
+
+void LatexGenerator::startConstraintType()
+{
+  t << "} : {\\em ";
+}
+
+void LatexGenerator::endConstraintType()
+{
+  t << "}]";
+}
+
+void LatexGenerator::startConstraintDocs()
+{
+}
+
+void LatexGenerator::endConstraintDocs()
+{
+}
+
+void LatexGenerator::endConstraintList()
+{
+  t << "\\end{description}" << endl;
+  t << "\\end{Desc}" << endl;
+}
+
+void LatexGenerator::escapeLabelName(const char *s)
+{
+  const char *p=s;
+  char str[2];
+  str[1]=0;
+  char c;
+  while ((c=*p++))
+  {
+    switch (c)
+    {
+      case '%': t << "\\%";       break;
+      case '|': t << "\\tt{\"|}"; break;
+      case '!': t << "\"!";       break;
+      default:  str[0]=c; docify(str); break;
+    }
+  }
+}
+
+void LatexGenerator::escapeMakeIndexChars(const char *s)
+{
+  const char *p=s;
+  char str[2];
+  str[1]=0;
+  char c;
+  while ((c=*p++))
+  {
+    switch (c)
+    {
+      case '!': t << "\"!"; break;
+      case '"': t << "\"\""; break;
+      case '@': t << "\"@"; break;
+      case '|': t << "\\tt{\"|}"; break;
+      case '[': t << "["; break;
+      case ']': t << "]"; break;
+      default:  str[0]=c; docify(str); break;
+    }
+  }
+}
+
+
