@@ -2,7 +2,7 @@
  *
  * $Id: outputgen.h,v 1.48 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -132,6 +132,11 @@ class BaseOutputDocInterface : public CodeOutputInterface
     /*! Starts a new paragraph */
     virtual void newParagraph()   = 0;
 
+    /*! Starts a new paragraph */
+    virtual void startParagraph() = 0;
+    /*! End a paragraph */
+    virtual void endParagraph() = 0;
+
     /*! Writes a link to an object in the documentation.
      *  \param ref    If this is non-zero, the object is to be found in
      *                an external documentation file.
@@ -292,6 +297,7 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endFile() = 0;
     virtual void startIndexSection(IndexSections) = 0;
     virtual void endIndexSection(IndexSections) = 0;
+    virtual void writePageLink(const char *,bool) = 0;
     virtual void startProjectNumber() = 0;
     virtual void endProjectNumber() = 0;
     virtual void writeStyleInfo(int part) = 0;
@@ -347,21 +353,23 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endIndent() = 0;
     virtual void writeSynopsis() = 0;
     virtual void startClassDiagram() = 0;
-    virtual void endClassDiagram(ClassDiagram &,const char *,const char *) = 0;
+    virtual void endClassDiagram(const ClassDiagram &,const char *,const char *) = 0;
     virtual void startDotGraph() = 0;
-    virtual void endDotGraph(DotClassGraph &g) = 0;
+    virtual void endDotGraph(const DotClassGraph &g) = 0;
     virtual void startInclDepGraph() = 0;
-    virtual void endInclDepGraph(DotInclDepGraph &g) = 0;
+    virtual void endInclDepGraph(const DotInclDepGraph &g) = 0;
     virtual void startGroupCollaboration() = 0;
-    virtual void endGroupCollaboration(DotGroupCollaboration &g) = 0;
+    virtual void endGroupCollaboration(const DotGroupCollaboration &g) = 0;
     virtual void startCallGraph() = 0;
-    virtual void endCallGraph(DotCallGraph &g) = 0;
+    virtual void endCallGraph(const DotCallGraph &g) = 0;
     virtual void startDirDepGraph() = 0;
-    virtual void endDirDepGraph(DotDirDeps &g) = 0;
-    virtual void writeGraphicalHierarchy(DotGfxHierarchyTable &g) = 0;
-    //virtual void startQuickIndexItem(const char *s,const char *l) = 0;
-    //virtual void endQuickIndexItem() = 0;
+    virtual void endDirDepGraph(const DotDirDeps &g) = 0;
+    virtual void writeGraphicalHierarchy(const DotGfxHierarchyTable &g) = 0;
+    virtual void startQuickIndices() = 0;
+    virtual void endQuickIndices() = 0;
     virtual void writeQuickLinks(bool compact,HighlightedItem hli) = 0;
+    virtual void startContents() = 0;
+    virtual void endContents() = 0;
     virtual void startTextBlock(bool) = 0;
     virtual void endTextBlock(bool) = 0;
     virtual void lastIndexPage() = 0;
@@ -376,6 +384,15 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void startParameterList(bool) = 0;
     virtual void endParameterList() = 0;
 
+    virtual void startConstraintList(const char *) = 0;
+    virtual void startConstraintParam() = 0;
+    virtual void endConstraintParam() = 0;
+    virtual void startConstraintType() = 0;
+    virtual void endConstraintType() = 0;
+    virtual void startConstraintDocs() = 0;
+    virtual void endConstraintDocs() = 0;
+    virtual void endConstraintList() = 0;
+
   protected:
     QTextStream fs;
     QByteArray a;
