@@ -3,7 +3,7 @@
  *
  *
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  * Authors: Dimitri van Heesch, Miguel Lobo.
  *
  * Permission to use, copy, modify, and distribute this software and its
@@ -484,16 +484,24 @@ void PerlModDocVisitor::closeSubBlock()
 
 void PerlModDocVisitor::openOther()
 {
+  // Using a secondary text stream will corrupt the perl file. Instead of
+  // printing doc => [ data => [] ], it will print doc => [] data => [].
+  /*
   leaveText();
   m_output.openSave();
+  */
 }
 
 void PerlModDocVisitor::closeOther()
 {
+  // Using a secondary text stream will corrupt the perl file. Instead of
+  // printing doc => [ data => [] ], it will print doc => [] data => [].
+  /*
   QString other;
   leaveText();
   m_output.closeSave(other);
   m_other += other;
+  */
 }
 
 void PerlModDocVisitor::visit(DocWord *w)
@@ -1153,6 +1161,7 @@ void PerlModDocVisitor::visitPre(DocParamSect *s)
   case DocParamSect::Param:     type = "params"; break;
   case DocParamSect::RetVal:    type = "retvals"; break;
   case DocParamSect::Exception: type = "exceptions"; break;
+  case DocParamSect::TemplateParam: type = "templateparam"; break;
   case DocParamSect::Unknown:
     err("Error: unknown parameter section found\n");
     break;
@@ -1414,7 +1423,7 @@ void PerlModGenerator::generatePerlModForMember(MemberDef *md,Definition *)
   switch (md->memberType())
   {
   case MemberDef::Define:      memType="define";    break;
-  case MemberDef::EnumValue:   ASSERT(0);           break;
+  case MemberDef::EnumValue:   memType="enumvalue"; break;
   case MemberDef::Property:    memType="property";  break;
   case MemberDef::Variable:    memType="variable";  break;
   case MemberDef::Typedef:     memType="typedef";   break;
@@ -1692,10 +1701,13 @@ void PerlModGenerator::generatePerlModForClass(ClassDef *cd)
 
   addTemplateList(cd,m_output);
   addListOfAllMembers(cd);
-  MemberGroupSDict::Iterator mgli(*cd->getMemberGroupSDict());
-  MemberGroup *mg;
-  for (;(mg=mgli.current());++mgli)
-    generatePerlModSection(cd,mg->members(),"user_defined",mg->header());
+  if (cd->getMemberGroupSDict())
+  {
+    MemberGroupSDict::Iterator mgli(*cd->getMemberGroupSDict());
+    MemberGroup *mg;
+    for (;(mg=mgli.current());++mgli)
+      generatePerlModSection(cd,mg->members(),"user_defined",mg->header());
+  }
 
   generatePerlModSection(cd,cd->getMemberList(MemberList::pubTypes),"public_typedefs");
   generatePerlModSection(cd,cd->getMemberList(MemberList::pubMethods),"public_methods");
@@ -1795,10 +1807,13 @@ void PerlModGenerator::generatePerlModForNamespace(NamespaceDef *nd)
     m_output.closeList();
   }
 
-  MemberGroupSDict::Iterator mgli(*nd->getMemberGroupSDict());
-  MemberGroup *mg;
-  for (;(mg=mgli.current());++mgli)
-    generatePerlModSection(nd,mg->members(),"user-defined",mg->header());
+  if (nd->getMemberGroupSDict())
+  {
+    MemberGroupSDict::Iterator mgli(*nd->getMemberGroupSDict());
+    MemberGroup *mg;
+    for (;(mg=mgli.current());++mgli)
+      generatePerlModSection(nd,mg->members(),"user-defined",mg->header());
+  }
 
   generatePerlModSection(nd,nd->getMemberList(MemberList::decDefineMembers),"defines");
   generatePerlModSection(nd,nd->getMemberList(MemberList::decProtoMembers),"prototypes");
@@ -1967,10 +1982,13 @@ void PerlModGenerator::generatePerlModForGroup(GroupDef *gd)
     m_output.closeList();
   }
 
-  MemberGroupSDict::Iterator mgli(*gd->getMemberGroupSDict());
-  MemberGroup *mg;
-  for (;(mg=mgli.current());++mgli)
-    generatePerlModSection(gd,mg->members(),"user-defined",mg->header());
+  if (gd->getMemberGroupSDict())
+  {
+    MemberGroupSDict::Iterator mgli(*gd->getMemberGroupSDict());
+    MemberGroup *mg;
+    for (;(mg=mgli.current());++mgli)
+      generatePerlModSection(gd,mg->members(),"user-defined",mg->header());
+  }
 
   generatePerlModSection(gd,gd->getMemberList(MemberList::decDefineMembers),"defines");
   generatePerlModSection(gd,gd->getMemberList(MemberList::decProtoMembers),"prototypes");
