@@ -2,7 +2,7 @@
  *
  * $Id: rtfgen.h,v 1.13 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2007 by Parker Waechter & Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Parker Waechter & Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -31,9 +31,6 @@ class RTFGenerator : public OutputGenerator
     static void writeStyleSheetFile(QFile &f);
     static void writeExtensionsFile(QFile &file);
 
-    //OutputGenerator *copy();
-    //OutputGenerator *clone() { return new RTFGenerator(*this); }
-    //void append(const OutputGenerator *o);
     void enable() 
     { if (genStack->top()) active=*genStack->top(); else active=TRUE; }
     void disable() { active=FALSE; }
@@ -51,10 +48,9 @@ class RTFGenerator : public OutputGenerator
     void clearBuffer();
     void postProcess(QByteArray &);
     
-    //void writeIndex();
-	
     void startIndexSection(IndexSections);
     void endIndexSection(IndexSections);
+    void writePageLink(const char *,bool);
     void startProjectNumber();
     void endProjectNumber();
     void writeStyleInfo(int part);
@@ -64,6 +60,8 @@ class RTFGenerator : public OutputGenerator
     void endTitle() {} 
 
     void newParagraph();
+    void startParagraph();
+    void endParagraph();
     void writeString(const char *text);
     void startIndexList();
     void endIndexList();
@@ -108,8 +106,6 @@ class RTFGenerator : public OutputGenerator
     void endMemberItem();
     void startMemberTemplateParams() {}
     void endMemberTemplateParams() {}
-    //void memberGroupSpacing(bool) {}
-    //void memberGroupSeparator() {}
     void insertMemberAlign(bool) {}
 
     void writeRuler() { rtfwriteRuler_thin(); }
@@ -117,15 +113,9 @@ class RTFGenerator : public OutputGenerator
     void writeAnchor(const char *fileName,const char *name);
     void startCodeFragment();
     void endCodeFragment();
-    //void startPreFragment()      { startCodeFragment(); }
-    //void endPreFragment()        { endCodeFragment(); }
-    //void startVerbatimFragment() { startCodeFragment(); }
-    //void endVerbatimFragment()   { endCodeFragment(); }
     void writeLineNumber(const char *,const char *,const char *,int l) { t << l << " "; }
     void startCodeLine() { col=0; }
     void endCodeLine() { lineBreak(); }
-    //void writeBoldString(const char *text) 
-    //                     { t << "{\\b "; docify(text); t << "}"; }
     void startEmphasis() { t << "{\\i ";  }
     void endEmphasis()   { t << "}"; }
     void startBold()     { t << "{\\b "; }
@@ -143,7 +133,6 @@ class RTFGenerator : public OutputGenerator
     void endCodeAnchor() {};
     void writeChar(char c);
     void writeLatexSpacing() {};//{ t << "\\hspace{0.3cm}"; }
-    //void writeLatexLabel(const char *scope,const char *anchor);
     void writeStartAnnoItem(const char *type,const char *file, 
                             const char *path,const char *name);
     void writeEndAnnoItem(const char *name);
@@ -155,64 +144,31 @@ class RTFGenerator : public OutputGenerator
     void endCenter()        { t << "}"; }
     void startSmall()       { t << "{\\sub "; }
     void endSmall()         { t << "}"; }
-    //void startSubscript()   { t << "{\\sub " << endl;}
-    //void endSubscript()     { t << "}"; }
-    //void startSuperscript() { t << "{\\super " << endl;}
-    //void endSuperscript()   { t << "}"; }
-    //void startTable(bool,int);
-    //void endTable(bool);
-    //void startCaption();
-    //void endCaption();
-    //void nextTableRow();
-    //void endTableRow();
-    //void nextTableColumn();
-    //void endTableColumn();
-    //void writeCopyright()    { t << "\251"; }
-    //void writeQuote()        { t << "\""; }
-    //void writeUmlaut(char c);
-    //void writeAcute(char c);
-    //void writeGrave(char c);
-    //void writeCirc(char c);
-    //void writeTilde(char c);
-    //void writeRing(char c);
-    //void writeSharpS()       { t << "\337"; }
-    //void writeCCedil(char c);
 
     void startMemberDescription();
     void endMemberDescription();
     void startDescList(SectionTypes);
-    //void endDescList();
     void startSimpleSect(SectionTypes,const char *,const char *,const char *);
     void endSimpleSect();
     void startParamList(ParamListTypes,const char *);
     void endParamList();
-    //void endDescTitle();
     void writeDescItem();
     void startSection(const char *,const char *,SectionInfo::SectionType);
     void endSection(const char *,SectionInfo::SectionType);
-    //void writeSectionRef(const char *,const char *,const char *,const char *);
-    //void writeSectionRefItem(const char *,const char *,const char *);
-    //void writeSectionRefAnchor(const char *,const char *,const char *);
     void addIndexItem(const char *,const char *);
     void startIndent();
     void endIndent();
     void writeSynopsis()     {}
-    //void generateExternalIndex() {}
     void startClassDiagram();
-    void endClassDiagram(ClassDiagram &,const char *filename,const char *name);
-    //void startColorFont(uchar,uchar,uchar) {}
-    //void endColorFont()   {}
+    void endClassDiagram(const ClassDiagram &,const char *filename,const char *name);
     void startPageRef();
     void endPageRef(const char *,const char *);
-    //void startQuickIndexItem(const char *,const char *) {}
-    //void endQuickIndexItem() {}
+    void startQuickIndices() {}
+    void endQuickIndices() {}
     void writeQuickLinks(bool,HighlightedItem) {}
-    //void writeFormula(const char *,const char *);
+    void startContents() {}
+    void endContents() {}
     void writeNonBreakableSpace(int);
-    //void startImage(const char *,const char *,bool);
-    //void endImage(bool);
-    //void startDotFile(const char *,bool);
-    //void endDotFile(bool);
 	
     void startDescTable();
     void endDescTable();
@@ -222,16 +178,16 @@ class RTFGenerator : public OutputGenerator
     void endDescTableData();
     
     void startDotGraph();
-    void endDotGraph(DotClassGraph &);
+    void endDotGraph(const DotClassGraph &);
     void startInclDepGraph();
-    void endInclDepGraph(DotInclDepGraph &);
+    void endInclDepGraph(const DotInclDepGraph &);
     void startGroupCollaboration();
-    void endGroupCollaboration(DotGroupCollaboration &g);
+    void endGroupCollaboration(const DotGroupCollaboration &g);
     void startCallGraph();
-    void endCallGraph(DotCallGraph &);
+    void endCallGraph(const DotCallGraph &);
     void startDirDepGraph();
-    void endDirDepGraph(DotDirDeps &g);
-    void writeGraphicalHierarchy(DotGfxHierarchyTable &) {}
+    void endDirDepGraph(const DotDirDeps &g);
+    void writeGraphicalHierarchy(const DotGfxHierarchyTable &) {}
 
     void startMemberGroupHeader(bool);
     void endMemberGroupHeader();
@@ -248,24 +204,26 @@ class RTFGenerator : public OutputGenerator
     void endMemberDocPrefixItem() {}
     void startMemberDocName(bool) {}
     void endMemberDocName() {}
-    void startParameterType(bool,const char *) {}
+    void startParameterType(bool,const char *);
     void endParameterType() {}
     void startParameterName(bool) {}
     void endParameterName(bool,bool,bool) {}
     void startParameterList(bool) {}
     void endParameterList() {}
 
+    void startConstraintList(const char  *);
+    void startConstraintParam();
+    void endConstraintParam();
+    void startConstraintType();
+    void endConstraintType();
+    void startConstraintDocs();
+    void endConstraintDocs();
+    void endConstraintList();
+
+
     void startFontClass(const char *) {}
     void endFontClass() {}
 
-    //void startHtmlOnly()  {}
-    //void endHtmlOnly()    {}
-    //void startLatexOnly() {}
-    //void endLatexOnly()   {}
-
-    //void startSectionRefList() {}
-    //void endSectionRefList() {}
-
     void writeCodeAnchor(const char *) {}
     void linkableSymbol(int,const char *,Definition *,Definition *) {}
 
