@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -108,7 +108,8 @@ void XmlDocVisitor::visit(DocURL *u)
   if (m_hide) return;
   m_t << "<ulink url=\""; 
   if (u->isEmail()) m_t << "mailto:";
-  m_t << u->url() << "\">";
+  filter(u->url());
+  m_t << "\">";
   filter(u->url());
   m_t << "</ulink>";
 }
@@ -777,6 +778,8 @@ void XmlDocVisitor::visitPre(DocParamSect *s)
       m_t << "retval"; break;
     case DocParamSect::Exception: 
       m_t << "exception"; break;
+    case DocParamSect::TemplateParam: 
+      m_t << "templateparam"; break;
     default:
       ASSERT(0);
   }
@@ -875,7 +878,7 @@ void XmlDocVisitor::visitPost(DocInternalRef *)
 void XmlDocVisitor::visitPre(DocCopy *c)
 {
   if (m_hide) return;
-  m_t << "<copydoc link=\"" << c->link() << "\">";
+  m_t << "<copydoc link=\"" << convertToXML(c->link()) << "\">";
 }
 
 void XmlDocVisitor::visitPost(DocCopy *)
